@@ -1,4 +1,4 @@
-package App::MonM; # $Id: MonM.pm 51 2015-06-30 11:51:44Z abalama $
+package App::MonM; # $Id: MonM.pm 57 2016-10-04 12:46:30Z abalama $
 use strict;
 
 =head1 NAME
@@ -7,7 +7,7 @@ App::MonM - Simple Monitoring Tools
 
 =head1 VERSION
 
-Version 1.04
+Version 1.05
 
 =head1 SYNOPSIS
 
@@ -113,7 +113,7 @@ The method returns status of "checkit" request. See L<monm> and README for detai
 
 The method returns status of "checkitreport" request. See L<monm> and README for details
 
-=item B<alertgrid_init, alertgrid_clear, alertgrid_config, alertgrid_server, alertgrid_client, alertgrid_snapshot, alertgrid_export>
+=item B<alertgrid_init, alertgrid_clear, alertgrid_config, alertgrid_server, alertgrid_client, alertgrid_snapshot, alertgrid_export, alertgrid_normalize>
 
     my $status = $monm->alertgrid_server( '' );
 or
@@ -176,7 +176,7 @@ See C<LICENSE> file
 =cut
 
 use vars qw/ $VERSION /;
-$VERSION = '1.04';
+$VERSION = '1.05';
 
 use CTKx;
 use CTK::Util;
@@ -1055,7 +1055,7 @@ sub checkitreport {
         $ma{'-message'} .= "\n---\n"
             . sprintf("Generated by    : MonM/%s\n", $VERSION)
             . sprintf("Date generation : %s\n", localtime2date_time())
-            . sprintf("MonM Id         : %s\n", '$Id: MonM.pm 51 2015-06-30 11:51:44Z abalama $')
+            . sprintf("MonM Id         : %s\n", '$Id: MonM.pm 57 2016-10-04 12:46:30Z abalama $')
             . sprintf("Time Stamp      : %s\n", $c->tms())
             . sprintf("Configuration   : %s\n", $c->cfgfile)
             . sprintf("Statistic file  : %s\n", $ymlfile)
@@ -1129,6 +1129,34 @@ sub alertgrid_clear {
     _show_result_data(\$rslt, $self->opt("utf8")) if $self->opt('verbose');
     $self->status;
 }
+sub alertgrid_normalize {
+    my $self = shift;
+    my %data = @_;
+    my $c = $self->ctkx->c;
+    my $config = $c->config;
+    
+    my $dbfile = value($config, 'alertgrid/server/dbfile') || catfile($c->datadir,$data{dbfile});
+    debug "DBFile: ", $dbfile;
+    
+    start "AlertGrid normalizing";
+    my $stt = ag_normalize($dbfile);
+    my $msg = "";
+    if ($stt) {
+        finish DONE;
+    } else {
+        $self->status(FALSE);
+        $self->message(ERROR);
+        $self->error(sprintf "File %s not exists", $dbfile);
+        finish ERROR;
+    }
+    
+    #  / 
+    my $rslt = $self->foutput("alertgrid", {
+            dbfile  => $dbfile,
+        });
+    _show_result_data(\$rslt, $self->opt("utf8")) if $self->opt('verbose');
+    $self->status;
+}
 sub alertgrid_config {
     my $self = shift;
     my %data = @_;
