@@ -1,4 +1,4 @@
-package App::MonM::RRDtool; # $Id: RRDtool.pm 36 2014-12-13 14:00:21Z abalama $
+package App::MonM::RRDtool; # $Id: RRDtool.pm 65 2016-10-05 14:53:02Z abalama $
 use strict;
 
 =head1 NAME
@@ -7,7 +7,7 @@ App::MonM::RRDtool - App::MonM RRDtool interface
 
 =head1 VIRSION
 
-Version 1.00
+Version 1.01
 
 =head1 SYNOPSIS
 
@@ -101,7 +101,7 @@ See C<LICENSE> file
 =cut
 
 use vars qw/$VERSION/;
-$VERSION = '1.00';
+$VERSION = '1.01';
 
 my $RRDs_loaded = 0;
 
@@ -213,11 +213,13 @@ sub create {
             my $rrderror = RRDs::error();
             $err = $rrderror ? sprintf("%s: Unable to create \"%s\": %s\n",$0,$file,$rrderror) : '';
         } else {
-            $msg = exe([$self->{maker},
+            my $cmd = [$self->{maker},
                     "-f", catfile(sharedir(), 'monm', 'Makefile.net'),
                     "create",
                     sprintf("FILE=%s", $file),
-                ], undef, \$err);
+                ];
+            $self->_debug(join " ", @$cmd);
+            $msg = exe($cmd, undef, \$err);
         }
     } elsif ($type eq "resources") {
         if ($self->is_loaded) {
@@ -242,18 +244,54 @@ sub create {
             my $rrderror = RRDs::error();
             $err = $rrderror ? sprintf("%s: Unable to create \"%s\": %s\n",$0,$file,$rrderror) : '';
         } else {
-            $msg = exe([$self->{maker},
+            my $cmd = [$self->{maker},
                     "-f", catfile(sharedir(), 'monm', 'Makefile.res'),
                     "create",
                     sprintf("FILE=%s", $file),
-                ], undef, \$err);
+                ];
+            $self->_debug(join " ", @$cmd);
+            $msg = exe($cmd, undef, \$err);
         }
+    } elsif ($type eq "single") {
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.sng'),
+                "create",
+                sprintf("FILE=%s", $file),
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+    } elsif ($type eq "double") {
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.dbl'),
+                "create",
+                sprintf("FILE=%s", $file),
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+    } elsif ($type eq "triple") {
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.trp'),
+                "create",
+                sprintf("FILE=%s", $file),
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+    } elsif ($type eq "quadruple") {
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.qdr'),
+                "create",
+                sprintf("FILE=%s", $file),
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+    
     } else {
         $err = "Unsupported type";
     }
 
     $self->_debug($msg);    
     if ($err) {
+        $self->_debug($err);
         $self->error($err);
         $self->status(0);
     }
@@ -333,14 +371,16 @@ sub update {
             my $rrderror = RRDs::error();
             $err = $rrderror ? sprintf("%s: Unable to update \"%s\": %s\n",$0,$file,$rrderror) : '';
         } else {
-            $msg = exe([$self->{maker},
+            my $cmd = [$self->{maker},
                     "-f", catfile(sharedir(), 'monm', 'Makefile.net'),
                     "update",
                     sprintf("FILE=%s", $file),
                     sprintf("PUBDATE=%s", $src_pubdate || 'N'),
                     sprintf("INPUT=%s", $src_input || 0),
                     sprintf("OUTPUT=%s", $src_output || 0),
-                ], undef, \$err);
+                ];
+            $self->_debug(join " ", @$cmd);
+            $msg = exe($cmd, undef, \$err);
         }
         
     } elsif ($type eq "resources") {
@@ -363,7 +403,7 @@ sub update {
             my $rrderror = RRDs::error();
             $err = $rrderror ? sprintf("%s: Unable to update \"%s\": %s\n",$0,$file,$rrderror) : '';
         } else {
-            $msg = exe([$self->{maker},
+            my $cmd = [$self->{maker},
                     "-f", catfile(sharedir(), 'monm', 'Makefile.res'),
                     "update",
                     sprintf("FILE=%s", $file),
@@ -372,15 +412,85 @@ sub update {
                     sprintf("HDD=%s", $src_hdd || 0),
                     sprintf("MEM=%s", $src_mem || 0),
                     sprintf("SWP=%s", $src_swp || 0),
-                ], undef, \$err);
+                ];
+            $self->_debug(join " ", @$cmd);
+            $msg = exe($cmd, undef, \$err);
         }
+
+    } elsif ($type eq "single") {
+        my $src_pubdate = value($struct{(value($sources, 'srcusr1') || 'USR1')}, 'pubdate');
+        my $src_usr1    = value($struct{(value($sources, 'srcusr1') || 'USR1')}, 'value');
+        #print STDERR "USR1: $src_usr1";
+        #print STDERR "PUB: $src_pubdate";
         
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.sng'),
+                "update",
+                sprintf("FILE=%s", $file),
+                sprintf("PUBDATE=%s", $src_pubdate || 'N'),
+                sprintf("USR1=%s", $src_usr1 || 0),
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+    } elsif ($type eq "double") {
+        my $src_pubdate = value($struct{(value($sources, 'srcusr1') || 'USR1')}, 'pubdate');
+        my $src_usr1    = value($struct{(value($sources, 'srcusr1') || 'USR1')}, 'value');
+        my $src_usr2    = value($struct{(value($sources, 'srcusr2') || 'USR2')}, 'value');
+        
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.dbl'),
+                "update",
+                sprintf("FILE=%s", $file),
+                sprintf("PUBDATE=%s", $src_pubdate || 'N'),
+                sprintf("USR1=%s", $src_usr1 || 0),
+                sprintf("USR2=%s", $src_usr2 || 0),
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+    } elsif ($type eq "triple") {
+        my $src_pubdate = value($struct{(value($sources, 'srcusr1') || 'USR1')}, 'pubdate');
+        my $src_usr1    = value($struct{(value($sources, 'srcusr1') || 'USR1')}, 'value');
+        my $src_usr2    = value($struct{(value($sources, 'srcusr2') || 'USR2')}, 'value');
+        my $src_usr3    = value($struct{(value($sources, 'srcusr3') || 'USR3')}, 'value');
+        
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.trp'),
+                "update",
+                sprintf("FILE=%s", $file),
+                sprintf("PUBDATE=%s", $src_pubdate || 'N'),
+                sprintf("USR1=%s", $src_usr1 || 0),
+                sprintf("USR2=%s", $src_usr2 || 0),
+                sprintf("USR3=%s", $src_usr3 || 0),
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+    } elsif ($type eq "quadruple") {
+        my $src_pubdate = value($struct{(value($sources, 'srcusr1') || 'USR1')}, 'pubdate');
+        my $src_usr1    = value($struct{(value($sources, 'srcusr1') || 'USR1')}, 'value');
+        my $src_usr2    = value($struct{(value($sources, 'srcusr2') || 'USR2')}, 'value');
+        my $src_usr3    = value($struct{(value($sources, 'srcusr3') || 'USR3')}, 'value');
+        my $src_usr4    = value($struct{(value($sources, 'srcusr4') || 'USR4')}, 'value');
+        
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.qdr'),
+                "update",
+                sprintf("FILE=%s", $file),
+                sprintf("PUBDATE=%s", $src_pubdate || 'N'),
+                sprintf("USR1=%s", $src_usr1 || 0),
+                sprintf("USR2=%s", $src_usr2 || 0),
+                sprintf("USR3=%s", $src_usr3 || 0),
+                sprintf("USR4=%s", $src_usr4 || 0),
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+
     } else {
         $err = "Unsupported type";
     }
     
     $self->_debug($msg);    
     if ($err) {
+        $self->_debug($err);
         $self->error($err);
         $self->status(0);
     }
@@ -401,7 +511,25 @@ sub graph {
     my $odir = $in{dir} || _get_dbpath();
     my $mask = $in{mask} || MASK;
     my $image;
+    my $fle = $file; $fle =~ s/\:/\\\:/g; # 
     
+    my @graph_a = (
+        "graph",
+        sprintf("FILE=%s", $fle),
+        sprintf("NAME=%s", $name),
+        #sprintf("PUBDATE=\"%s\"", dtf("%w, %DD %MON %YYYY %hh\\:%mm\\:%ss %Z",time())),
+        sprintf("PUBDATE=%s", dtf("%w, %DD %MON %YYYY %hh\\:%mm\\:%ss",time())),
+        sprintf("MINI=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "mini" }))),
+        sprintf("QUARTER=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "quarter" }))),
+        sprintf("DAILY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "daily" }))),
+        sprintf("WEEKLY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "weekly" }))),
+        sprintf("MONTHLY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "monthly" }))),
+        sprintf("YEARLY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "yearly" }))),
+        sprintf("BRD_D=%s", _vborder("daily")),
+        sprintf("BRD_W=%s", _vborder("weekly")),
+        sprintf("BRD_M=%s", _vborder("monthly")),
+        sprintf("BRD_Y=%s", _vborder("yearly")),
+    );
     
     # See http://oss.oetiker.ch/rrdtool/tut/rrdtutorial.en.html
     my ($msg, $err);
@@ -540,24 +668,12 @@ sub graph {
             my $rrderror = RRDs::error();
             $err = $rrderror ? sprintf("%s: Unable to create image \"%s\": %s\n",$0,$file,$rrderror) : '';
         } else {
-            my $fle = $file; $fle =~ s/\:/\\\:/g;
-            $msg = exe([$self->{maker},
+            my $cmd = [$self->{maker},
                     "-f", catfile(sharedir(), 'monm', 'Makefile.net'),
-                    "graph",
-                    sprintf("FILE=%s", $fle),
-                    sprintf("NAME=%s", $name),
-                    sprintf("PUBDATE=\"%s\"", dtf("%w, %DD %MON %YYYY %hh\\:%mm\\:%ss %Z",time())),
-                    sprintf("MINI=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "mini" }))),
-                    sprintf("QUARTER=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "quarter" }))),
-                    sprintf("DAILY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "daily" }))),
-                    sprintf("WEEKLY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "weekly" }))),
-                    sprintf("MONTHLY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "monthly" }))),
-                    sprintf("YEARLY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "yearly" }))),
-                    sprintf("BRD_D=%s", _vborder("daily")),
-                    sprintf("BRD_W=%s", _vborder("weekly")),
-                    sprintf("BRD_M=%s", _vborder("monthly")),
-                    sprintf("BRD_Y=%s", _vborder("yearly")),
-                ], undef, \$err);
+                    @graph_a
+                ];
+            $self->_debug(join " ", @$cmd);
+            $msg = exe($cmd, undef, \$err);
             #print "$err\n" if $err;
         }
     } elsif ($type eq "resources") {
@@ -721,35 +837,55 @@ sub graph {
             my $rrderror = RRDs::error();
             $err = $rrderror ? sprintf("%s: Unable to create image \"%s\": %s\n",$0,$file,$rrderror) : '';
         } else {
-            my $fle = $file; $fle =~ s/\:/\\\:/g;
-            $msg = exe([$self->{maker},
+            my $cmd = [$self->{maker},
                     "-f", catfile(sharedir(), 'monm', 'Makefile.res'),
-                    "graph",
-                    sprintf("FILE=%s", $fle),
-                    sprintf("NAME=%s", $name),
-                    sprintf("PUBDATE=\"%s\"", dtf("%w, %DD %MON %YYYY %hh\\:%mm\\:%ss %Z",time())),
-                    sprintf("MINI=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "mini" }))),
-                    sprintf("QUARTER=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "quarter" }))),
-                    sprintf("DAILY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "daily" }))),
-                    sprintf("WEEKLY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "weekly" }))),
-                    sprintf("MONTHLY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "monthly" }))),
-                    sprintf("YEARLY=%s", catfile($odir, dformat($mask, { EXT => "png", TYPE => $type, KEY => $name, GTYPE => "yearly" }))),
-                    sprintf("BRD_D=%s", _vborder("daily")),
-                    sprintf("BRD_W=%s", _vborder("weekly")),
-                    sprintf("BRD_M=%s", _vborder("monthly")),
-                    sprintf("BRD_Y=%s", _vborder("yearly")),
-                ], undef, \$err);
+                    @graph_a
+                ];
+            $self->_debug(join " ", @$cmd);
+            $msg = exe($cmd, undef, \$err);
             #print "$err\n" if $err;
         }
+    } elsif ($type eq "single") {
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.sng'),
+                @graph_a,
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+        #print "$err\n" if $err;
+    } elsif ($type eq "double") {
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.dbl'),
+                @graph_a,
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+    } elsif ($type eq "triple") {
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.trp'),
+                @graph_a,
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
+    } elsif ($type eq "quadruple") {
+        my $cmd = [$self->{maker},
+                "-f", catfile(sharedir(), 'monm', 'Makefile.qdr'),
+                @graph_a,
+            ];
+        $self->_debug(join " ", @$cmd);
+        $msg = exe($cmd, undef, \$err);
     } else {
         $err = "Unsupported type";
     }
 
-    $self->_debug($msg);    
+    $self->_debug($msg);
     if ($err) {
+        $self->_debug($err);
         $self->error($err);
         $self->status(0);
-    }    
+    } else {
+        $self->status(1);
+    }
     
     return $self->status;
 }
