@@ -1,4 +1,4 @@
-package App::MonM::Skel::Config; # $Id: Config.pm 40 2014-12-16 14:48:05Z abalama $
+package App::MonM::Skel::Config; # $Id: Config.pm 58 2016-10-05 09:49:47Z abalama $
 use strict;
 
 use CTK::Util qw/ :BASE /;
@@ -6,7 +6,7 @@ use CTK::Util qw/ :BASE /;
 use constant SIGNATURE => "config";
 
 use vars qw($VERSION);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 sub build { #  
     my $self = shift;
@@ -420,18 +420,29 @@ Mode: 644
 
     <Count "bar">
         Enable      yes
+        
         Type        command
         Command     "cat data/2.xml"
     </Count>
 
     <Count "baz">
         Enable      yes
+        
         Type        command
         Command     "cat data/3.xml"
     </Count>
+
     <Count "qux">
         Enabled     no
     </Count>
+
+    <Count "nginx_test">
+        Enable     yes
+
+        Type command
+        command "alertgrid_nginx -q http://nginx.myhost.com/server-status"
+    </Count>
+
 </AlertGrid>
 
 -----END FILE-----
@@ -539,18 +550,29 @@ Type: Windows
 
     <Count "bar">
         Enable     yes
+        
         Type        command
         Command     "cat data/2.xml"
     </Count>
 
     <Count "baz">
         Enable     yes
+        
         Type        command
         Command     "cat data/3.xml"
     </Count>
+    
     <Count "qux">
         Enabled     no
     </Count>
+
+    <Count "nginx_test">
+        Enable     yes
+
+        Type command
+        command "alertgrid_nginx -q http://nginx.myhost.com/server-status"
+    </Count>
+
 </AlertGrid>
 
 -----END FILE-----
@@ -596,6 +618,41 @@ Mode: 644
     <Graph "baz">
         Enable no
     </Graph>
+    
+    <Graph "single">
+        Enable yes
+        Type single
+        File "/root/single.rrd"
+        SRCUSR1	127.0.0.1::test::nginx_cc::nginx::stub::requests
+    </Graph>
+
+    <Graph "double">
+        Enable yes
+        Type double
+        File "/root/double.rrd"
+        SRCUSR1	127.0.0.1::test::nginx_test::nginx::stub::active
+        SRCUSR2	127.0.0.1::test::nginx_test::nginx::stub::waiting
+    </Graph>
+
+    <Graph "triple">
+        Enable yes
+        Type triple
+        File "/root/triple.rrd"
+        SRCUSR1	127.0.0.1::test::nginx_test::nginx::stub::active
+        SRCUSR2	127.0.0.1::test::nginx_test::nginx::stub::writing
+        SRCUSR3	127.0.0.1::test::nginx_test::nginx::stub::waiting
+    </Graph>
+    
+    <Graph "quadruple">
+        Enable yes
+        Type quadruple
+        File "/root/quadruple.rrd"
+        SRCUSR1	127.0.0.1::test::nginx_test::nginx::stub::active
+        SRCUSR2	127.0.0.1::test::nginx_test::nginx::stub::writing
+        SRCUSR3	127.0.0.1::test::nginx_test::nginx::stub::waiting
+        SRCUSR4	127.0.0.1::test::nginx_test::nginx::test
+    </Graph>
+
 </RRD>
 
 -----END FILE-----
\ No newline at end of file
